@@ -28,6 +28,335 @@ from ._jsii import *
 import aws_cdk.core
 
 
+@jsii.implements(aws_cdk.core.IInspectable)
+class CfnDataCatalog(
+    aws_cdk.core.CfnResource,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-athena.CfnDataCatalog",
+):
+    """A CloudFormation ``AWS::Athena::DataCatalog``.
+
+    see
+    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html
+    cloudformationResource:
+    :cloudformationResource:: AWS::Athena::DataCatalog
+    """
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        name: str,
+        type: str,
+        description: typing.Optional[str] = None,
+        parameters: typing.Optional[
+            typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
+        ] = None,
+        tags: typing.Optional["TagsProperty"] = None,
+    ) -> None:
+        """Create a new ``AWS::Athena::DataCatalog``.
+
+        :param scope: - scope in which this resource is defined.
+        :param id: - scoped id of the resource.
+        :param name: ``AWS::Athena::DataCatalog.Name``.
+        :param type: ``AWS::Athena::DataCatalog.Type``.
+        :param description: ``AWS::Athena::DataCatalog.Description``.
+        :param parameters: ``AWS::Athena::DataCatalog.Parameters``.
+        :param tags: ``AWS::Athena::DataCatalog.Tags``.
+        """
+        props = CfnDataCatalogProps(
+            name=name,
+            type=type,
+            description=description,
+            parameters=parameters,
+            tags=tags,
+        )
+
+        jsii.create(CfnDataCatalog, self, [scope, id, props])
+
+    @jsii.member(jsii_name="fromCloudFormation")
+    @builtins.classmethod
+    def from_cloud_formation(
+        cls,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: aws_cdk.core.ICfnFinder,
+    ) -> "CfnDataCatalog":
+        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
+
+        Used in the @aws-cdk/cloudformation-include module.
+
+        :param scope: -
+        :param id: -
+        :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
+
+        stability
+        :stability: experimental
+        """
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
+
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
+    @jsii.member(jsii_name="renderProperties")
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
+        """
+        :param props: -
+        """
+        return jsii.invoke(self, "renderProperties", [props])
+
+    @jsii.python.classproperty
+    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
+    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+        """The CloudFormation resource type name for this resource class."""
+        return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
+
+    @builtins.property
+    @jsii.member(jsii_name="cfnProperties")
+    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+        return jsii.get(self, "cfnProperties")
+
+    @builtins.property
+    @jsii.member(jsii_name="tags")
+    def tags(self) -> aws_cdk.core.TagManager:
+        """``AWS::Athena::DataCatalog.Tags``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-tags
+        """
+        return jsii.get(self, "tags")
+
+    @builtins.property
+    @jsii.member(jsii_name="name")
+    def name(self) -> str:
+        """``AWS::Athena::DataCatalog.Name``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-name
+        """
+        return jsii.get(self, "name")
+
+    @name.setter
+    def name(self, value: str) -> None:
+        jsii.set(self, "name", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="type")
+    def type(self) -> str:
+        """``AWS::Athena::DataCatalog.Type``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-type
+        """
+        return jsii.get(self, "type")
+
+    @type.setter
+    def type(self, value: str) -> None:
+        jsii.set(self, "type", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="description")
+    def description(self) -> typing.Optional[str]:
+        """``AWS::Athena::DataCatalog.Description``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-description
+        """
+        return jsii.get(self, "description")
+
+    @description.setter
+    def description(self, value: typing.Optional[str]) -> None:
+        jsii.set(self, "description", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="parameters")
+    def parameters(
+        self,
+    ) -> typing.Optional[
+        typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
+    ]:
+        """``AWS::Athena::DataCatalog.Parameters``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-parameters
+        """
+        return jsii.get(self, "parameters")
+
+    @parameters.setter
+    def parameters(
+        self,
+        value: typing.Optional[
+            typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
+        ],
+    ) -> None:
+        jsii.set(self, "parameters", value)
+
+    @jsii.data_type(
+        jsii_type="@aws-cdk/aws-athena.CfnDataCatalog.TagsProperty",
+        jsii_struct_bases=[],
+        name_mapping={"tags": "tags"},
+    )
+    class TagsProperty:
+        def __init__(
+            self, *, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None
+        ) -> None:
+            """
+            :param tags: ``CfnDataCatalog.TagsProperty.Tags``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-datacatalog-tags.html
+            """
+            self._values = {}
+            if tags is not None:
+                self._values["tags"] = tags
+
+        @builtins.property
+        def tags(self) -> typing.Optional[typing.List[aws_cdk.core.CfnTag]]:
+            """``CfnDataCatalog.TagsProperty.Tags``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-datacatalog-tags.html#cfn-athena-datacatalog-tags-tags
+            """
+            return self._values.get("tags")
+
+        def __eq__(self, rhs) -> bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs) -> bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "TagsProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
+
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-athena.CfnDataCatalogProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "name": "name",
+        "type": "type",
+        "description": "description",
+        "parameters": "parameters",
+        "tags": "tags",
+    },
+)
+class CfnDataCatalogProps:
+    def __init__(
+        self,
+        *,
+        name: str,
+        type: str,
+        description: typing.Optional[str] = None,
+        parameters: typing.Optional[
+            typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
+        ] = None,
+        tags: typing.Optional["CfnDataCatalog.TagsProperty"] = None,
+    ) -> None:
+        """Properties for defining a ``AWS::Athena::DataCatalog``.
+
+        :param name: ``AWS::Athena::DataCatalog.Name``.
+        :param type: ``AWS::Athena::DataCatalog.Type``.
+        :param description: ``AWS::Athena::DataCatalog.Description``.
+        :param parameters: ``AWS::Athena::DataCatalog.Parameters``.
+        :param tags: ``AWS::Athena::DataCatalog.Tags``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html
+        """
+        if isinstance(tags, dict):
+            tags = CfnDataCatalog.TagsProperty(**tags)
+        self._values = {
+            "name": name,
+            "type": type,
+        }
+        if description is not None:
+            self._values["description"] = description
+        if parameters is not None:
+            self._values["parameters"] = parameters
+        if tags is not None:
+            self._values["tags"] = tags
+
+    @builtins.property
+    def name(self) -> str:
+        """``AWS::Athena::DataCatalog.Name``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-name
+        """
+        return self._values.get("name")
+
+    @builtins.property
+    def type(self) -> str:
+        """``AWS::Athena::DataCatalog.Type``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-type
+        """
+        return self._values.get("type")
+
+    @builtins.property
+    def description(self) -> typing.Optional[str]:
+        """``AWS::Athena::DataCatalog.Description``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-description
+        """
+        return self._values.get("description")
+
+    @builtins.property
+    def parameters(
+        self,
+    ) -> typing.Optional[
+        typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
+    ]:
+        """``AWS::Athena::DataCatalog.Parameters``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-parameters
+        """
+        return self._values.get("parameters")
+
+    @builtins.property
+    def tags(self) -> typing.Optional["CfnDataCatalog.TagsProperty"]:
+        """``AWS::Athena::DataCatalog.Tags``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-datacatalog.html#cfn-athena-datacatalog-tags
+        """
+        return self._values.get("tags")
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "CfnDataCatalogProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.implements(aws_cdk.core.IInspectable)
 class CfnNamedQuery(
     aws_cdk.core.CfnResource,
@@ -1229,6 +1558,8 @@ class CfnWorkGroupProps:
 
 
 __all__ = [
+    "CfnDataCatalog",
+    "CfnDataCatalogProps",
     "CfnNamedQuery",
     "CfnNamedQueryProps",
     "CfnWorkGroup",
